/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.variable.service.impl.types;

import org.flowable.variable.api.types.ValueFields;
import org.flowable.variable.api.types.VariableType;

/**
 * Custom object type
 * 
 * @author Esteban Robles Luna
 */
public class CustomObjectType implements VariableType {

    protected String typeName;
    protected Class<?> theClass;

    public CustomObjectType(String typeName, Class<?> theClass) {
        this.theClass = theClass;
        this.typeName = typeName;
    }

    @Override
    public String getTypeName() {
        return this.typeName;
    }

    @Override
    public Object getValue(ValueFields valueFields) {
        return valueFields.getCachedValue();
    }

    @Override
    public boolean isAbleToStore(Object value) {
        if (value == null) {
            return true;
        }
        return this.theClass.isAssignableFrom(value.getClass());
    }

    @Override
    public boolean isCachable() {
        return true;
    }

    @Override
    public void setValue(Object value, ValueFields valueFields) {
        valueFields.setCachedValue(value);
    }
}
